@@ -1,7 +1,9 @@
 import requests
 import json
 
-from .song.SongResult import SongResult
+from .entity.song.SongResult import SongResult
+from .entity.album.AlbumResult import AlbumResult
+from .entity.EntityResult import EntityResult
 
 BASE_URL = 'https://api.song.link'
 API_VERSION = 'v1-alpha.1'
@@ -12,8 +14,7 @@ class Odesli():
     def __init__(self, key=None):
         self.key = key
 
-    def getByUrl(self, url):
-        params = { 'url': url }
+    def __get(self, params) -> EntityResult:
         if not self.key == None:
             params['key'] = self.key
         requestResult = requests.get(f'{ROOT}/{LINKS_ENDPOINT}', params=params)
@@ -23,7 +24,17 @@ class Odesli():
         if resultType == 'song':
             return SongResult.parse(result)
         elif resultType == 'album':
-            return None
-            # return AlbumResult.parse(result)
+            return AlbumResult.parse(result)
         else:
             raise NotImplementedError(f'Entities with type {resultType} are not supported yet.')
+
+
+    def getByUrl(self, url) -> EntityResult:
+        return self.__get({ 'url': url })
+
+    def getById(self, id, platform, type) -> EntityResult:
+        return self.__get({
+            'id': id,
+            'platform': platform,
+            'type': type
+        })
